﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Telerik.Windows.Controls;

namespace ColumnGroups
{
	public partial class ColumnGroup : UserControl
	{
		public ColumnGroup(GridViewColumn firstColumn, GridViewColumn lastColumn, string caption)
		{
			InitializeComponent();
			this.FirstColumn = firstColumn;
			this.LastColumn = lastColumn;
			this.Caption = caption;
			this.LastColumn = lastColumn;
			this.Caption = caption;
			this.HorizontalAlignment = HorizontalAlignment.Left;
			this.VerticalAlignment = VerticalAlignment.Top;
			this.Loaded += new RoutedEventHandler(ColumnGroup_Loaded);
			this.Indent = 5;
			this.SetValue(Grid.ColumnProperty, 2);

		}


		
		public static readonly DependencyProperty CaptionProperty =
			DependencyProperty.Register("Caption", typeof(string), typeof(ColumnGroup), new PropertyMetadata(String.Empty, CaptionChanged));

		
		public string Caption
		{
			get
			{
				return (string) this.GetValue(CaptionProperty);
			}
			set
			{
				this.SetValue(CaptionProperty, value);
			}
		}




		public double Indent { get; set; }

		private RadGridView parentGrid;
		void ColumnGroup_Loaded(object sender, RoutedEventArgs e)
		{
			this.parentGrid = this.ParentOfType<RadGridView>();
			this.parentGrid.ItemsControl.VirtualizingPanel.ScrollOwner.HorizontalScrollChanged += new EventHandler<System.Windows.Controls.Primitives.ScrollEventArgs>(ScrollOwner_HorizontalScrollChanged);
			foreach (GridViewColumn column in this.parentGrid.Columns)
			{
				column.PropertyChanged += new System.ComponentModel.PropertyChangedEventHandler(column_PropertyChanged);
			}

			AlignToColumns();
			
		}

		double horizontalScrollOffset;
		void ScrollOwner_HorizontalScrollChanged(object sender, System.Windows.Controls.Primitives.ScrollEventArgs e)
		{
			this.horizontalScrollOffset = e.NewValue;
			this.AlignToColumns();
		}

		static void CaptionChanged(DependencyObject sender, DependencyPropertyChangedEventArgs args)
		{
			((ColumnGroup)sender).CaptionTextBlock.Text = (string) args.NewValue;
		}

		void column_PropertyChanged(object sender, System.ComponentModel.PropertyChangedEventArgs e)
		{
			if (e.PropertyName == "ActualWidth")
				this.AlignToColumns();
		}

		private void AlignToColumns()
		{
			

			double startPosition = 0;
			double endPosition = 0;
			double offset = 0;
			foreach (GridViewColumn column in this.parentGrid.Columns)
			{
				if (column == this.FirstColumn)
				{
					startPosition = offset;
				}

				

				offset += column.ActualWidth;
				if (column == this.LastColumn)
					endPosition = offset;
			}

			this.Margin = new Thickness(startPosition + Indent - horizontalScrollOffset, 0, 0, 0);
			this.Width = endPosition - startPosition;
		}

		public GridViewColumn FirstColumn { get; set; }
		public GridViewColumn LastColumn { get; set; }
	}
}
